package
Version:
v0.1.1
Opens a new window with list of versions in this module.
Published: Jan 9, 2026
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type MACPolicy struct {
AllowAllZero bool
AllowBroadcast bool
AllowMulticast bool
AllowLocallyAdmin bool
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.